#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "TEA","my secret key";
RandomIV"ĢOSA0PYYz
`7k껕T;!Oeo 4q/pť<EгĮB'[V̀0=8|r%PB^ʷnrnf&Le"n`y,/^@Z